import com.huawei.sis.bean.AuthInfo;
import com.huawei.sis.bean.SisConfig;
import com.huawei.sis.bean.SisConstant;
import com.huawei.sis.bean.request.AsrShortRequest;
import com.huawei.sis.bean.response.AsrShortResponse;
import com.huawei.sis.client.AsrClient;
import com.huawei.sis.exception.SisException;
import com.huawei.sis.util.IOUtils;
import com.huawei.sis.util.JsonUtils;

/**
 * 短语音识别demo
 * <p>
 * Copyright 2020 Huawei Technologies Co.,Ltd.
 */
public class AsrDemo {

  private String ak = "";
  private String sk = "";
  private String region = "";       // 区域，如cn-north-1

  private String path = "";         // 本地音频路径，需具体到文件，如d:/test.wav
  private String obsUrl = "";       // obs音频链接，音频传送支持本地文件或者obs链接。目前仅支持同一用户，同一region

  /**
   * 短语音识别参数设置，所有参数均有默认值，不配置也可使用。
   *
   * @return request
   */
  private void setShortParameter(AsrShortRequest request) throws SisException {
    // 设置待识别的音频的base64字符串，要求不超过1min。与obsUrl二选一设置。
    String base64Str = IOUtils.getEncodeDataByPath(path);
    request.setData(base64Str);
    // 也可以通过obsUrl传入待识别音频。若两者都设置，默认使用传入的data
    // request.setObsUrl(obsUrl);
    // 设置采样率，目前支持8k，16k。默认是8k。详见api文档
    request.setSampleRate("8k");
    // 设置文件的类型，支持wav、mp3、wma、amr、ac3、ogg、aac等。 可不填赋值空串。详见api文档
    request.setEncodeType("");

  }

  /**
   * 定义config，所有参数可选，设置超时时间等。
   *
   * @return SisConfig
   */
  private SisConfig getConfig() {
    SisConfig config = new SisConfig();
    // 设置连接超时，默认10000ms
    config.setConnectionTimeout(SisConstant.DEFAULT_CONNECTION_TIMEOUT);
    // 设置读取超时，默认10000ms
    config.setReadTimeout(SisConstant.DEFAULT_READ_TIMEOUT);
    // 设置代理, 一定要确保代理可用才启动此设置。 代理初始化也可用不加密的代理，new ProxyHostInfo(host, port);
    // ProxyHostInfo proxy = new ProxyHostInfo(host, port, username, password);
    // config.setProxy(proxy);
    return config;
  }

  /**
   * 短语音识别。
   */
  private void shortDemo() {
    try {
      // 1. 初始化AsrClient
      // 定义authInfo，根据ak，sk，region
      AuthInfo authInfo = new AuthInfo(ak, sk, region);
      // 设置config，主要与超时有关
      SisConfig config = getConfig();
      // 根据authInfo和config，构造AsrClient
      AsrClient asr = new AsrClient(authInfo, config);

      // 2. 配置请求
      AsrShortRequest request = new AsrShortRequest();
      setShortParameter(request);

      // 3. 发送请求，获取响应.具体结果可通过response.getXX获取。
      AsrShortResponse response = asr.getAsrShortResponse(request);
      // 打印结果
      System.out.println(JsonUtils.obj2Str(response, true));

    } catch (SisException e) {
      e.printStackTrace();
      System.out.println("error_code:" + e.getErrorCode() + "\nerror_msg:" + e.getErrorMsg());
    }
  }

  public static void main(String[] args) {
    try {
      AsrDemo demo = new AsrDemo();
      demo.shortDemo();

    } catch (Exception e) {
      e.printStackTrace();
    }

  }
}
